@@ -4,12 +4,14 @@
 
 ./configure \
   $PKGCFG \
-  $CROSSCFG \
-  --with-ptw32=/opt/mxe/usr/i686-pc-mingw32 \
+  --host=i686-w64-mingw32.static \
+  --with-ptw32=$PREFIX/i686-w64-mingw32.static \
+  --enable-static \
   PTW32_LIBS="-lpthread -lpcreposix -lpcre" \
-  FLTK_CONFIG=$PREFIX/bin/i686-pc-mingw32-fltk-config
+  FLTK_CONFIG=$PREFIX/bin/i686-w64-mingw32.static-fltk-config
 
-make
+make clean
+make -j 4
 
 $PREFIX/bin/i686-pc-mingw32-strip src/flwrap.exe
 make nsisinst
