@@ -83,25 +83,25 @@ const char *wrap_fn = "[WRAP:fn ";
 Ccrc16 chksum;
 base64 b64(1); // insert lf for ease of viewing
 
-string inptext = "";
-string check = "";
-string outfilename = "";
-string inpfilename = "";
-string inpshortname = "";
-string outshortname = "";
-string foldername = "";
+std::string inptext = "";
+std::string check = "";
+std::string outfilename = "";
+std::string inpfilename = "";
+std::string inpshortname = "";
+std::string outshortname = "";
+std::string foldername = "";
 
-string errtext = "";
-string infotext = "";
+std::string errtext = "";
+std::string infotext = "";
 
 bool usecompression = false;
 
-void dress(string &str)
+void dress(std::string &str)
 {
-	string s = "";
+	std::string s = "";
 	if (str.empty()) return;
 	size_t p = 0;
-	string rpl = "";
+	std::string rpl = "";
 	unsigned char ch;
 	for (p = 0; p < str.length(); p++) {
 		ch = str[p] & 0xFF;
@@ -124,11 +124,11 @@ void dress(string &str)
 	str = s;
 }
 
-void strip(string &s)
+void strip(std::string &s)
 {
 	if (s.empty()) return;
 	size_t p = 0;
-	string str = "";
+	std::string str = "";
 	while (p < s.length()) {
 		if (s[p] != '|') str += s[p];
 		else {
@@ -167,28 +167,28 @@ bool isExtension(const char *s1, const char *s2)
 
 void base64encode()
 {
-	string outtext;
+	std::string outtext;
 	outtext = b64.encode(inptext);
 	inptext = b64_start;
 	inptext.append(outtext);
 	inptext.append(b64_end);
 }
 
-void convert2crlf(string &s)
+void convert2crlf(std::string &s)
 {
-	if (s.find('\r') != string::npos) return;
+	if (s.find('\r') != std::string::npos) return;
 	size_t p = s.find('\n');
-	while (p != string::npos) {
+	while (p != std::string::npos) {
 		s.replace(p, 1, "\r\n");
 		p = s.find('\n', p + 2);
 	}
 }
 
-void convert2lf(string &s)
+void convert2lf(std::string &s)
 {
 	size_t p = s.find("\r\n");
 
-	while (p != string::npos) {
+	while (p != std::string::npos) {
 		s.replace(p, 2, "\n");
 		p = s.find("\r\n");
 	}
@@ -196,7 +196,7 @@ void convert2lf(string &s)
 
 #define LZMA_STR "\1LZMA"
 
-bool compress_always(string &input)
+bool compress_always(std::string &input)
 {
 	// allocate 105% of the original size for the output buffer
 	size_t outlen = (size_t)ceil(input.length() * 1.05);
@@ -227,7 +227,7 @@ bool compress_always(string &input)
 	return true;
 }
 
-void decompress_maybe(string& input)
+void decompress_maybe(std::string& input)
 {
 	// input is LZMA_STR + original size (in network byte order) + props + data
 	if (input.find(LZMA_STR)) {
@@ -280,13 +280,13 @@ bool wrapfile(bool isbinary)
 		if (!compress_always(inptext)) return false;
 		base64encode();
 	} else {
-		if (inptext.find("\r\n") != string::npos) {
+		if (inptext.find("\r\n") != std::string::npos) {
 			iscrlf = true;
 			convert2lf(inptext); // checksum & data transfer always based on Unix end-of-line char
 		}
 	}
 
-	string originalfilename = wrap_fn;
+	std::string originalfilename = wrap_fn;
 	originalfilename.append(inpshortname);
 	originalfilename += ']';
 
@@ -327,23 +327,23 @@ bool wrapfile(bool isbinary)
 bool unwrapfile()
 {
 	size_t p1, p2, p3, p4;
-	string wtext;
-	string testsum;
-	string inpsum;
+	std::string wtext;
+	std::string testsum;
+	std::string inpsum;
 	bool iscrlf = false;
 
 	p1 = inptext.find(wrap_beg);
-	if (p1 == string::npos) {
+	if (p1 == std::string::npos) {
 		errtext = "Not a wrap file";
 		return false;
 	}
 	p1 = inptext.find(wrap_crlf);
-	if (p1 != string::npos) { // original text had crlf pairs
+	if (p1 != std::string::npos) { // original text had crlf pairs
 		iscrlf = true;
 		p1 += strlen(wrap_crlf);
 	} else {
 		p1 = inptext.find(wrap_lf);
-		if (p1 == string::npos) {
+		if (p1 == std::string::npos) {
 			errtext = "Invalid file";
 			return false;
 		}
@@ -351,23 +351,23 @@ bool unwrapfile()
 	}
 
 	p2 = inptext.find(wrap_chksum, p1);
-	if (p2 == string::npos) return false;
+	if (p2 == std::string::npos) return false;
 	wtext = inptext.substr(p1, p2-p1); // this is the original document
 
 	p3 = p2 + strlen(wrap_chksum);
 	p4 = inptext.find(']', p3);
-	if (p4 == string::npos) {
+	if (p4 == std::string::npos) {
 		errtext = "Cannot find checksum in file";
 		return false;
 	}
 	inpsum = inptext.substr(p3, p4-p3);
 	p4 = inptext.find(wrap_end, p4);
-	if (p4 == string::npos) {
+	if (p4 == std::string::npos) {
 		errtext = "No end tag in file";
 		return false;
 	}
 
-	if (wtext.find("\r\n") != string::npos)
+	if (wtext.find("\r\n") != std::string::npos)
 		convert2lf(wtext);
 
 	testsum = chksum.scrc16(wtext);
@@ -387,18 +387,18 @@ bool unwrapfile()
 		outshortname.erase(0, strlen(wrap_fn));
 		wtext.erase(0,p+1);
 // check for protocol abuse
-bool t1 = (outshortname.find('/') != string::npos);
-bool t2 = (outshortname.find('\\') != string::npos);
+bool t1 = (outshortname.find('/') != std::string::npos);
+bool t2 = (outshortname.find('\\') != std::string::npos);
 bool t3 = (outshortname == ".");
 bool t4 = (outshortname == "..");
-bool t5 = (outshortname.find(":") != string::npos);
+bool t5 = (outshortname.find(":") != std::string::npos);
 bool t6 = outshortname.empty();
 		if (t1 || t2 || t3 || t4 || t5 || t6) {
 			errtext = "Filename corrupt, possible protocol abuse\n";
 			if (t1) errtext.append("Filename contains '/' character\n");
 			if (t2) errtext.append("Filename contains '\\' character\n");
 			if (t3) errtext.append("Filename contains leading '.' character\n");
-			if (t4) errtext.append("Filename contains leading '..' string\n");
+			if (t4) errtext.append("Filename contains leading '..' std::string\n");
 			if (t5) errtext.append("Filename contains MS directory specifier\n");
 			if (t6) errtext.append("Filename is empty\n");
 			return false;
@@ -407,7 +407,7 @@ bool t6 = outshortname.empty();
 		outfilename.append(outshortname);
 	} else {
 		p1 = outfilename.find(".wrap");
-		if (p1 != string::npos)
+		if (p1 != std::string::npos)
 			outfilename.erase(p1);
 	}
 
@@ -415,10 +415,10 @@ bool t6 = outshortname.empty();
 		convert2crlf(wtext);
 
 	p1 = wtext.find(b64_start);
-	if (p1 != string::npos) {
+	if (p1 != std::string::npos) {
 		p1 += strlen(b64_start);
 		p2 = wtext.find(b64_end, p1);
-		if (p2 == string::npos) {
+		if (p2 == std::string::npos) {
 			errtext = "Base 64 decode failed";
 			return false;
 		}
@@ -484,7 +484,7 @@ void wrap_unwrap()
 	} else {
 		if (usecompression) isbinary = true;
 
-		if (inptext.find("[WRAP:") == string::npos) {
+		if (inptext.find("[WRAP:") == std::string::npos) {
 			if (!wrapfile(isbinary))
 				snprintf(result, sizeof(result), "%s\n", errtext.c_str());
 			else {
@@ -517,11 +517,11 @@ void wrap_unwrap()
 int main(int argc, char **argv)
 {
 	Fl_Window *mainwin = make_window();
-	string Title = "Flwrap ";
+	std::string Title = "Flwrap ";
 	Title.append(VERSION);
 	mainwin->label(Title.c_str());
 
-	string argvs = "";
+	std::string argvs = "";
 	for (int i = 0; i < argc; i++) argvs.append(argv[i]).append(" ");
 
 	int arg_idx;
@@ -573,14 +573,14 @@ int parse_args(int argc, char **argv, int& idx)
 
 void inpDropBox_changed()
 {
-	string fname;
-	size_t n = string::npos;
+	std::string fname;
+	size_t n = std::string::npos;
 	fname = inpDropBox->value();
-	if ((n = fname.find("file:///")) != string::npos)
+	if ((n = fname.find("file:///")) != std::string::npos)
 		fname.erase(n, 7);
-	while ((n = fname.find('\n')) != string::npos)
+	while ((n = fname.find('\n')) != std::string::npos)
 		fname.erase(n, 1);
-	while ((n = fname.find('\r')) != string::npos)
+	while ((n = fname.find('\r')) != std::string::npos)
 		fname.erase(n, 1);
 	inpDropBox->value(fname.c_str());
 	inpfilename = outfilename = fname;
