@@ -4,6 +4,8 @@
 //
 //=====================================================================
 
+#include <string>
+
 class Ccrc16 {
 private:
 	unsigned int crcval;
@@ -13,7 +15,7 @@ public:
 	~Ccrc16() {};
 	void reset() { crcval = 0xFFFF;}
 	unsigned int val() {return crcval;}
-	string sval() {
+	std::string sval() {
 		sprintf(ss,"%04X", crcval);
 		return ss;
 	}
@@ -30,13 +32,13 @@ public:
 		update(c); 
 		return crcval;
 	}
-	unsigned int crc16(string s) {
+	unsigned int crc16(std::string s) {
 		reset();
 		for (size_t i = 0; i < s.length(); i++)
 			update(s[i]);
 		return crcval;
 	}
-	string scrc16(string s) {
+	std::string scrc16(std::string s) {
 		crc16(s);
 		return sval();
 	}
